desk package
============

Submodules
----------

desk.config module
------------------

.. automodule:: desk.config
    :members:
    :undoc-members:
    :show-inheritance:

desk.get\_remote\_models module
-------------------------------

.. automodule:: desk.get_remote_models
    :members:
    :undoc-members:
    :show-inheritance:

desk.parameter\_ranges module
-----------------------------

.. automodule:: desk.parameter_ranges
    :members:
    :undoc-members:
    :show-inheritance:

desk.plotting\_seds module
--------------------------

.. automodule:: desk.plotting_seds
    :members:
    :undoc-members:
    :show-inheritance:

desk.sed\_fit module
--------------------

.. automodule:: desk.sed_fit
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: desk
    :members:
    :undoc-members:
    :show-inheritance:
